==> haskell-ranged-sets-0.3.0-14-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-ranged-sets.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: Ranged-sets
version: 0.3.0
id: Ranged-sets-0.3.0-IVqwPqonijmBiSQsuY7IQL
key: Ranged-sets-0.3.0-IVqwPqonijmBiSQsuY7IQL
license: BSD-3-Clause
copyright: Paul Johnson, 2005, 2006, 2007, 2008
maintainer: paul@cogito.org.uk
author: Paul Johnson
stability: beta
homepage: http://code.haskell.org/ranged-sets
synopsis: Ranged sets for Haskell
description:
    A ranged set is an ordered list of ranges.  This allows sets such as all reals x such that:
    .
    > (0.25 < x <= 0.75 or 1.4 <= x < 2.3 or 4.5 < x)
    .
    Alternatively you can have all strings s such that:
    .
    >    ("F" <= s < "G")
category: Data
abi: 9fb8fc4b1711a19c280f975a4fa4bd83
exposed: True
exposed-modules:
    Data.Ranged Data.Ranged.Boundaries Data.Ranged.RangedSet
    Data.Ranged.Ranges
import-dirs: /usr/lib/ghc-8.4.3/site-local/Ranged-sets-0.3.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/Ranged-sets-0.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/Ranged-sets-0.3.0
hs-libraries: HSRanged-sets-0.3.0-IVqwPqonijmBiSQsuY7IQL
depends:
    HUnit-1.6.0.0-8OmbxYW4AG9PppbZs26Xx
    QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr base-4.11.1.0
abi-depends: HUnit-1.6.0.0-8OmbxYW4AG9PppbZs26Xx=6ff9610fd5e59ec310c47074d0590847
             QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr=59a035869ce3bae16d8c8360447f600f
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
haddock-interfaces: /usr/share/doc/haskell-ranged-sets/html/Ranged-sets.haddock
haddock-html: /usr/share/doc/haskell-ranged-sets/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ranged-sets-0.3.0-15-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-ranged-sets.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: Ranged-sets
version: 0.3.0
id: Ranged-sets-0.3.0-8gFs7ALmLaUFZYpRw3Mued
key: Ranged-sets-0.3.0-8gFs7ALmLaUFZYpRw3Mued
license: BSD-3-Clause
copyright: Paul Johnson, 2005, 2006, 2007, 2008
maintainer: paul@cogito.org.uk
author: Paul Johnson
stability: beta
homepage: http://code.haskell.org/ranged-sets
synopsis: Ranged sets for Haskell
description:
    A ranged set is an ordered list of ranges.  This allows sets such as all reals x such that:
    .
    > (0.25 < x <= 0.75 or 1.4 <= x < 2.3 or 4.5 < x)
    .
    Alternatively you can have all strings s such that:
    .
    >    ("F" <= s < "G")
category: Data
abi: c58eb624cfcc1106cbf769477dd01c9d
exposed: True
exposed-modules:
    Data.Ranged Data.Ranged.Boundaries Data.Ranged.RangedSet
    Data.Ranged.Ranges
import-dirs: /usr/lib/ghc-8.6.1/site-local/Ranged-sets-0.3.0
library-dirs: /usr/lib/ghc-8.6.1/site-local/Ranged-sets-0.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/Ranged-sets-0.3.0
hs-libraries: HSRanged-sets-0.3.0-8gFs7ALmLaUFZYpRw3Mued
depends:
    HUnit-1.6.0.0-Kc3RXVOuMSQ9Y4PmNrdWEj
    QuickCheck-2.11.3-BDoyaQh2Mcq3pIdI4VETKc base-4.12.0.0
haddock-interfaces: /usr/share/doc/haskell-ranged-sets/html/Ranged-sets.haddock
haddock-html: /usr/share/doc/haskell-ranged-sets/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
